@@ -4,32 +4,19 @@
     """
 
 import numpy as np
+from numpy import cross
 from numpy.core.umath import cos, sin, sqrt
-
-from poliastro.core.angles import E_to_nu, F_to_nu
-from poliastro.core.util import cross, norm, rotation_matrix
+from numpy.linalg import norm
 
 from ._jit import jit
+from .angles import E_to_nu, F_to_nu
+from .util import rotation_matrix
 
 
 @jit
 def rv_pqw(k, p, ecc, nu):
     r"""Returns r and v vectors in perifocal frame.
 
-    .. math::
-
-        \vec{r} = \frac{h^2}{\mu}\frac{1}{1 + e\cos(\theta)}\begin{bmatrix}
-        \cos(\theta)\\
-        \sin(\theta)\\
-        0
-        \end{bmatrix} \\\\\\
-
-        \vec{v} = \frac{h^2}{\mu}\begin{bmatrix}
-        -\sin(\theta)\\
-        e+\cos(\theta)\\
-        0
-        \end{bmatrix}
-
     Parameters
     ----------
     k : float
@@ -49,30 +36,43 @@ def rv_pqw(k, p, ecc, nu):
     v: ndarray
         Velocity. Dimension 3 vector
 
+    Notes
+    -----
+    These formulas can be checked at Curtis 3rd. Edition, page 110. Also the
+    example proposed is 2.11 of Curtis 3rd Edition book.
+
+    .. math::
+
+        \vec{r} = \frac{h^2}{\mu}\frac{1}{1 + e\cos(\theta)}\begin{bmatrix}
+        \cos(\theta)\\
+        \sin(\theta)\\
+        0
+        \end{bmatrix} \\\\\\
+
+        \vec{v} = \frac{h^2}{\mu}\begin{bmatrix}
+        -\sin(\theta)\\
+        e+\cos(\theta)\\
+        0
+        \end{bmatrix}
+
     Examples
     --------
     >>> from poliastro.constants import GM_earth
-    >>> k = GM_earth #Earth gravitational parameter
-
-    >>> ecc = 0.3 #Eccentricity
-    >>> h = 60000e6 #Angular momentum of the orbit [m^2]/[s]
-    >>> nu = np.deg2rad(120) #True Anomaly [rad]
-    >>> p = h**2 / k #Parameter of the orbit
+    >>> k = GM_earth.value  # Earth gravitational parameter
+    >>> ecc = 0.3  # Eccentricity
+    >>> h = 60000e6  # Angular momentum of the orbit (m**2 / s)
+    >>> nu = np.deg2rad(120)  # True Anomaly (rad)
+    >>> p = h**2 / k  # Parameter of the orbit
     >>> r, v = rv_pqw(k, p, ecc, nu)
-
-    >>> #Printing the results
+    >>> # Printing the results
     r = [-5312706.25105345  9201877.15251336    0] [m]
     v = [-5753.30180931 -1328.66813933  0] [m]/[s]
 
-    Note
-    ----
-
-    These formulas can be checked at Curtis 3rd. Edition, page 110. Also the
-    example proposed is 2.11 of Curtis 3rd Edition book.
     """
-    r_pqw = (np.array([cos(nu), sin(nu), 0 * nu]) * p / (1 + ecc * cos(nu))).T
-    v_pqw = (np.array([-sin(nu), (ecc + cos(nu)), 0]) * sqrt(k / p)).T
-    return r_pqw, v_pqw
+    pqw = np.array([[cos(nu), sin(nu), 0], [-sin(nu), ecc + cos(nu), 0]]) * np.array(
+        [[p / (1 + ecc * cos(nu))], [sqrt(k / p)]]
+    )
+    return pqw
 
 
 @jit
@@ -93,27 +93,6 @@ def coe2rv(k, p, ecc, inc, raan, argp, nu):
     vectors by `rv_pqw` algorithm. A rotation matrix is applied to position
     and velocity vectors to get them expressed in terms of an IJK basis.
 
-        .. math::
-            \begin{align}
-                \vec{r}_{IJK} &= [ROT3(-\Omega)][ROT1(-i)][ROT3(-\omega)]\vec{r}_{PQW}
-                                   = \left [ \frac{IJK}{PQW} \right ]\vec{r}_{PQW}\\
-                \vec{v}_{IJK} &= [ROT3(-\Omega)][ROT1(-i)][ROT3(-\omega)]\vec{v}_{PQW}
-                                   = \left [ \frac{IJK}{PQW} \right ]\vec{v}_{PQW}\\
-            \end{align}
-
-    Previous rotations (3-1-3) can be expressed in terms of a single rotation matrix:
-
-        .. math::
-            \left [ \frac{IJK}{PQW} \right ]
-
-        .. math::
-            \begin{bmatrix}
-            \cos(\Omega)\cos(\omega) - \sin(\Omega)\sin(\omega)\cos(i) & -\cos(\Omega)\sin(\omega) - \sin(\Omega)\cos(\omega)\cos(i) & \sin(\Omega)\sin(i)\\
-            \sin(\Omega)\cos(\omega) + \cos(\Omega)\sin(\omega)\cos(i) & -\sin(\Omega)\sin(\omega) + \cos(\Omega)\cos(\omega)\cos(i) & -\cos(\Omega)\sin(i)\\
-            \sin(\omega)\sin(i) & \cos(\omega)\sin(i) & \cos(i)
-            \end{bmatrix}
-
-
     Parameters
     ----------
     k : float
@@ -134,17 +113,40 @@ def coe2rv(k, p, ecc, inc, raan, argp, nu):
     Returns
     -------
     r_ijk: np.array
-        Position vector in basis ijk
+        Position vector in basis ijk.
     v_ijk: np.array
-        Velocity vector in basis ijk
+        Velocity vector in basis ijk.
+
+    Notes
+    -----
+
+    .. math::
+        \begin{align}
+            \vec{r}_{IJK} &= [ROT3(-\Omega)][ROT1(-i)][ROT3(-\omega)]\vec{r}_{PQW}
+                               = \left [ \frac{IJK}{PQW} \right ]\vec{r}_{PQW}\\
+            \vec{v}_{IJK} &= [ROT3(-\Omega)][ROT1(-i)][ROT3(-\omega)]\vec{v}_{PQW}
+                               = \left [ \frac{IJK}{PQW} \right ]\vec{v}_{PQW}\\
+        \end{align}
+
+    Previous rotations (3-1-3) can be expressed in terms of a single rotation matrix:
+
+    .. math::
+        \left [ \frac{IJK}{PQW} \right ]
+
+    .. math::
+        \begin{bmatrix}
+        \cos(\Omega)\cos(\omega) - \sin(\Omega)\sin(\omega)\cos(i) & -\cos(\Omega)\sin(\omega) - \sin(\Omega)\cos(\omega)\cos(i) & \sin(\Omega)\sin(i)\\
+        \sin(\Omega)\cos(\omega) + \cos(\Omega)\sin(\omega)\cos(i) & -\sin(\Omega)\sin(\omega) + \cos(\Omega)\cos(\omega)\cos(i) & -\cos(\Omega)\sin(i)\\
+        \sin(\omega)\sin(i) & \cos(\omega)\sin(i) & \cos(i)
+        \end{bmatrix}
+
     """
-    r_pqw, v_pqw = rv_pqw(k, p, ecc, nu)
+    pqw = rv_pqw(k, p, ecc, nu)
     rm = coe_rotation_matrix(inc, raan, argp)
 
-    r_ijk = rm @ r_pqw
-    v_ijk = rm @ v_pqw
+    ijk = pqw @ rm.T
 
-    return r_ijk, v_ijk
+    return ijk
 
 
 @jit
@@ -161,16 +163,6 @@ def coe2mee(p, ecc, inc, raan, argp, nu):
     eccentricity and orbital inclinations equal to 0 and 90 degrees. However, two of the
     components are singular for an orbital inclination of 180 degrees.
 
-    .. math::
-        \begin{align}
-        p &= a(1-e^2) \\
-        f &= e\cos(\omega + \Omega) \\
-        g &= e\sin(\omega + \Omega) \\
-        h &= \tan(\frac{i}{2})\cos(\Omega) \\
-        k &= \tan(\frac{i}{2})\sin(\Omega) \\
-        L &= \Omega + \omega + \theta \\
-        \end{align}
-
     Parameters
     ----------
     k : float
@@ -203,9 +195,19 @@ def coe2mee(p, ecc, inc, raan, argp, nu):
     L: float
         Longitude
 
-    Note
+    Notes
     -----
-    The conversion equations are taken directly from the original paper.
+    The conversion equations are taken directly from the original paper:
+
+    .. math::
+        \begin{align}
+        p &= a(1-e^2) \\
+        f &= e\cos(\omega + \Omega) \\
+        g &= e\sin(\omega + \Omega) \\
+        h &= \tan(\frac{i}{2})\cos(\Omega) \\
+        k &= \tan(\frac{i}{2})\sin(\Omega) \\
+        L &= \Omega + \omega + \theta \\
+        \end{align}
 
     """
     lonper = raan + argp
@@ -222,48 +224,6 @@ def coe2mee(p, ecc, inc, raan, argp, nu):
 def rv2coe(k, r, v, tol=1e-8):
     r"""Converts from vectors to classical orbital elements.
 
-    1. First the angular momentum is computed:
-        .. math::
-            \vec{h} = \vec{r} \times \vec{v}
-
-    2. With it the eccentricity can be solved:
-        .. math::
-            \begin{align}
-            \vec{e} &= \frac{1}{\mu}\left [ \left ( v^{2} - \frac{\mu}{r}\right ) \vec{r}  - (\vec{r} \cdot \vec{v})\vec{v} \right ] \\
-            e &= \sqrt{\vec{e}\cdot\vec{e}} \\
-            \end{align}
-
-    3. The node vector line is solved:
-        .. math::
-            \begin{align}
-            \vec{N} &= \vec{k} \times \vec{h} \\
-            N &= \sqrt{\vec{N}\cdot\vec{N}}
-            \end{align}
-
-    4. The rigth ascension node is computed:
-        .. math::
-            \Omega = \left\{ \begin{array}{lcc}
-             cos^{-1}{\left ( \frac{N_{x}}{N} \right )} &   if  & N_{y} \geq  0 \\
-             \\ 360^{o} -cos^{-1}{\left ( \frac{N_{x}}{N} \right )} &  if & N_{y} < 0 \\
-             \end{array}
-            \right.
-
-    5. The argument of perigee:
-        .. math::
-            \omega  = \left\{ \begin{array}{lcc}
-             cos^{-1}{\left ( \frac{\vec{N}\vec{e}}{Ne} \right )} &   if  & e_{z} \geq  0 \\
-             \\ 360^{o} -cos^{-1}{\left ( \frac{\vec{N}\vec{e}}{Ne} \right )} &  if & e_{z} < 0 \\
-             \end{array}
-            \right.
-
-    6. And finally the true anomaly:
-        .. math::
-            \nu  = \left\{ \begin{array}{lcc}
-             cos^{-1}{\left ( \frac{\vec{e}\vec{r}}{er} \right )} &   if  & v_{r} \geq  0 \\
-             \\ 360^{o} -cos^{-1}{\left ( \frac{\vec{e}\vec{r}}{er} \right )} &  if & v_{r} < 0 \\
-             \end{array}
-            \right.
-
     Parameters
     ----------
     k : float
@@ -290,6 +250,59 @@ def rv2coe(k, r, v, tol=1e-8):
     nu: float
         True Anomaly (rad)
 
+    Notes
+    -----
+    This example is a real exercise from Orbital Mechanics for Engineering
+    students by Howard D.Curtis. This exercise is 4.3 of 3rd. Edition, page 200.
+
+    1. First the angular momentum is computed:
+
+    .. math::
+        \vec{h} = \vec{r} \times \vec{v}
+
+    2. With it the eccentricity can be solved:
+
+    .. math::
+        \begin{align}
+        \vec{e} &= \frac{1}{\mu}\left [ \left ( v^{2} - \frac{\mu}{r}\right ) \vec{r}  - (\vec{r} \cdot \vec{v})\vec{v} \right ] \\
+        e &= \sqrt{\vec{e}\cdot\vec{e}} \\
+        \end{align}
+
+    3. The node vector line is solved:
+
+    .. math::
+        \begin{align}
+        \vec{N} &= \vec{k} \times \vec{h} \\
+        N &= \sqrt{\vec{N}\cdot\vec{N}}
+        \end{align}
+
+    4. The rigth ascension node is computed:
+
+    .. math::
+        \Omega = \left\{ \begin{array}{lcc}
+         cos^{-1}{\left ( \frac{N_{x}}{N} \right )} &   if  & N_{y} \geq  0 \\
+         \\ 360^{o} -cos^{-1}{\left ( \frac{N_{x}}{N} \right )} &  if & N_{y} < 0 \\
+         \end{array}
+        \right.
+
+    5. The argument of perigee:
+
+    .. math::
+        \omega  = \left\{ \begin{array}{lcc}
+         cos^{-1}{\left ( \frac{\vec{N}\vec{e}}{Ne} \right )} &   if  & e_{z} \geq  0 \\
+         \\ 360^{o} -cos^{-1}{\left ( \frac{\vec{N}\vec{e}}{Ne} \right )} &  if & e_{z} < 0 \\
+         \end{array}
+        \right.
+
+    6. And finally the true anomaly:
+
+    .. math::
+        \nu  = \left\{ \begin{array}{lcc}
+         cos^{-1}{\left ( \frac{\vec{e}\vec{r}}{er} \right )} &   if  & v_{r} \geq  0 \\
+         \\ 360^{o} -cos^{-1}{\left ( \frac{\vec{e}\vec{r}}{er} \right )} &  if & v_{r} < 0 \\
+         \end{array}
+        \right.
+
     Examples
     --------
     >>> from poliastro.constants import GM_earth
@@ -307,14 +320,10 @@ def rv2coe(k, r, v, tol=1e-8):
     >>> print("raan:", np.rad2deg(raan), "[deg]")
     raan: 255.27928533439618 [deg]
     >>> print("argp:", np.rad2deg(argp), "[deg]")
-    argp: 20.068139973005366 [deg]
+    argp: 20.068139973005362 [deg]
     >>> print("nu:", np.rad2deg(nu), "[deg]")
     nu: 28.445804984192122 [deg]
 
-    Note
-    ----
-    This example is a real exercise from Orbital Mechanics for Engineering
-    students by Howard D.Curtis. This exercise is 4.3 of 3rd. Edition, page 200.
     """
 
     h = cross(r, v)
@@ -345,7 +354,7 @@ def rv2coe(k, r, v, tol=1e-8):
         ka = k * a
         if a > 0:
             e_se = r.dot(v) / sqrt(ka)
-            e_ce = norm(r) * (norm(v) ** 2) / k - 1
+            e_ce = norm(r) * v.dot(v) / k - 1
             nu = E_to_nu(np.arctan2(e_se, e_ce), ecc)
         else:
             e_sh = r.dot(v) / sqrt(-ka)
@@ -386,7 +395,7 @@ def mee2coe(p, f, g, h, k, L):
     p: float
         Semi-latus rectum
     f: float
-        Equinoctial parameter p
+        Equinoctial parameter f
     g: float
         Equinoctial parameter g
     h: float
