@@ -1,6 +1,6 @@
 import numpy as np
-
-from poliastro.core.util import norm
+from astropy import units as u
+from numpy.linalg import norm
 
 from ._jit import jit
 
@@ -82,7 +82,7 @@ def J3_perturbation(t0, state, k, J3, R):
 
 
 @jit
-def atmospheric_drag(t0, state, k, R, C_D, A, m, H0, rho0):
+def atmospheric_drag_exponential(t0, state, k, R, C_D, A_over_m, H0, rho0):
     r"""Calculates atmospheric drag acceleration (km/s2)
 
     .. math::
@@ -100,20 +100,21 @@ def atmospheric_drag(t0, state, k, R, C_D, A, m, H0, rho0):
         Six component state vector [x, y, z, vx, vy, vz] (km, km/s).
     k : float
         gravitational constant, (km^3/s^2)
+    R : float
+        radius of the attractor (km)
     C_D: float
         dimensionless drag coefficient ()
-    A: float
-        frontal area of the spacecraft (km^2)
-    m: float
-        mass of the spacecraft (kg)
+    A_over_m: float
+        frontal area/mass of the spacecraft (km^2/kg)
     H0 : float
         atmospheric scale height, (km)
     rho0: float
-        the exponent density pre-factor, (kg / m^3)
+        the exponent density pre-factor, (kg / km^3)
 
     Note
     ----
-    This function provides the acceleration due to atmospheric drag. We follow
+    This function provides the acceleration due to atmospheric drag
+    using an overly-simplistic exponential atmosphere model. We follow
     Howard Curtis, section 12.4
     the atmospheric density model is rho(H) = rho0 x exp(-H / H0)
 
@@ -122,12 +123,60 @@ def atmospheric_drag(t0, state, k, R, C_D, A, m, H0, rho0):
 
     v_vec = state[3:]
     v = norm(v_vec)
-    B = C_D * A / m
+    B = C_D * A_over_m
     rho = rho0 * np.exp(-(H - R) / H0)
 
     return -(1.0 / 2.0) * rho * B * v * v_vec
 
 
+def atmospheric_drag_model(t0, state, k, R, C_D, A_over_m, model):
+    r"""Calculates atmospheric drag acceleration (km/s2)
+
+    .. math::
+
+        \vec{p} = -\frac{1}{2}\rho v_{rel}\left ( \frac{C_{d}A}{m} \right )\vec{v_{rel}}
+
+
+    .. versionadded:: 1.14
+
+    Parameters
+    ----------
+    t0 : float
+        Current time (s)
+    state : numpy.ndarray
+        Six component state vector [x, y, z, vx, vy, vz] (km, km/s).
+    k : float
+        gravitational constant, (km^3/s^2)
+    R : float
+        radius of the attractor (km)
+    C_D: float
+        dimensionless drag coefficient ()
+    A_over_m: float
+        frontal area/mass of the spacecraft (km^2/kg)
+    model: a callable model from poliastro.atmosphere
+
+    Note
+    ----
+    This function provides the acceleration due to atmospheric drag, as
+    computed by a model from poliastro.atmosphere
+
+    """
+    H = norm(state[:3])
+
+    v_vec = state[3:]
+    v = norm(v_vec)
+    B = C_D * A_over_m
+
+    if H < R:
+        # the model doesn't want to see a negative altitude
+        # the integration will go a little negative searching for H = R
+        H = R
+
+    rho = model.density((H - R) * u.km).to(u.kg / u.km ** 3).value
+
+    return -(1.0 / 2.0) * rho * B * v * v_vec
+
+
 @jit
 def shadow_function(r_sat, r_sun, R):
     r"""Determines whether the satellite is in attractor's shadow, uses algorithm 12.3 from Howard Curtis
@@ -153,7 +202,7 @@ def shadow_function(r_sat, r_sun, R):
     return theta < theta_1 + theta_2
 
 
-def third_body(t0, state, k, k_third, third_body):
+def third_body(t0, state, k, k_third, perturbation_body):
     r"""Calculates 3rd body acceleration (km/s2)
 
     .. math::
@@ -168,8 +217,7 @@ def third_body(t0, state, k, k_third, third_body):
         Six component state vector [x, y, z, vx, vy, vz] (km, km/s).
     k : float
         gravitational constant, (km^3/s^2)
-    third_body: a callable object returning the position of 3rd body
-        third body that causes the perturbation
+    perturbation_body: a callable object returning the position of the pertubation body that causes the perturbation
 
     Note
     ----
@@ -178,12 +226,12 @@ def third_body(t0, state, k, k_third, third_body):
 
     """
 
-    body_r = third_body(t0)
+    body_r = perturbation_body(t0)
     delta_r = body_r - state[:3]
     return k_third * delta_r / norm(delta_r) ** 3 - k_third * body_r / norm(body_r) ** 3
 
 
-def radiation_pressure(t0, state, k, R, C_R, A, m, Wdivc_s, star):
+def radiation_pressure(t0, state, k, R, C_R, A_over_m, Wdivc_s, star):
     r"""Calculates radiation pressure acceleration (km/s2)
 
     .. math::
@@ -202,10 +250,8 @@ def radiation_pressure(t0, state, k, R, C_R, A, m, Wdivc_s, star):
         radius of the attractor
     C_R: float
         dimensionless radiation pressure coefficient, 1 < C_R < 2 ()
-    A: float
-        effective spacecraft area (km^2)
-    m: float
-        mass of the spacecraft (kg)
+    A_over_m: float
+        effective spacecraft area/mass of the spacecraft (km^2/kg)
     Wdivc_s : float
         total star emitted power divided by the speed of light (W * s / km)
     star: a callable object returning the position of star in attractor frame
@@ -223,4 +269,4 @@ def radiation_pressure(t0, state, k, R, C_R, A, m, Wdivc_s, star):
     P_s = Wdivc_s / (norm(r_star) ** 2)
 
     nu = float(shadow_function(r_sat, r_star, R))
-    return -nu * P_s * (C_R * A / m) * r_star / norm(r_star)
+    return -nu * P_s * (C_R * A_over_m) * r_star / norm(r_star)
