@@ -3,14 +3,14 @@
 """
 import numpy as np
 from astropy import units as u
+from numpy import cross
 
 from poliastro.core.elements import coe_rotation_matrix, rv_pqw
-from poliastro.core.util import cross
 from poliastro.iod.izzo import lambert as lambert_izzo
 from poliastro.util import norm
 
 
-class Maneuver(object):
+class Maneuver:
     r"""Class to represent a Maneuver.
 
     Each ``Maneuver`` consists on a list of impulses :math:`\Delta v_i`
@@ -48,6 +48,9 @@ class Maneuver(object):
         except TypeError:
             raise ValueError("Delta-V must be three dimensions vectors")
 
+    def __repr__(self):
+        return f"Number of impulses: {len(self.impulses)}, Total cost: {self.get_total_cost():.6f}"
+
     @u.quantity_input(dts=u.s, dvs=u.m / u.s)
     def _initialize(self, dts, dvs):
         return dts, dvs
@@ -97,8 +100,12 @@ class Maneuver(object):
             Final altitude of the orbit
         """
 
-        if orbit_i.nu is not 0 * u.deg:
+        # Propagate till periapsis
+        if orbit_i.nu != 0 * u.deg:
+            t_pericenter = orbit_i.time_to_anomaly(0 * u.deg)
             orbit_i = orbit_i.propagate_to_anomaly(0 * u.deg)
+        else:
+            t_pericenter = 0 * u.s
 
         # Initial orbit data
         k = orbit_i.attractor.k
@@ -141,7 +148,10 @@ class Maneuver(object):
 
         t_trans = np.pi * np.sqrt(a_trans ** 3 / k)
 
-        return cls((0 * u.s, dv_a), (t_trans, dv_b))
+        return cls(
+            (t_pericenter.decompose(), dv_a.decompose()),
+            (t_trans.decompose(), dv_b.decompose()),
+        )
 
     @classmethod
     def bielliptic(cls, orbit_i, r_b, r_f):
@@ -184,8 +194,13 @@ class Maneuver(object):
         r_f: astropy.unit.Quantity
             Final altitude of the orbit
         """
-        if orbit_i.nu is not 0 * u.deg:
+
+        # Propagate till periapsis
+        if orbit_i.nu != 0 * u.deg:
+            t_pericenter = orbit_i.time_to_anomaly(0 * u.deg)
             orbit_i = orbit_i.propagate_to_anomaly(0 * u.deg)
+        else:
+            t_pericenter = 0 * u.s
 
         # Initial orbit data
         k = orbit_i.attractor.k
@@ -234,11 +249,15 @@ class Maneuver(object):
         t_trans1 = np.pi * np.sqrt(a_trans1 ** 3 / k)
         t_trans2 = np.pi * np.sqrt(a_trans2 ** 3 / k)
 
-        return cls((0 * u.s, dv_a), (t_trans1, dv_b), (t_trans2, dv_c))
+        return cls(
+            (t_pericenter.decompose(), dv_a.decompose()),
+            (t_trans1.decompose(), dv_b.decompose()),
+            (t_trans2.decompose(), dv_c.decompose()),
+        )
 
     @classmethod
     def lambert(cls, orbit_i, orbit_f, method=lambert_izzo, short=True, **kwargs):
-        """ Computes lambert maneuver between two different points.
+        """Computes Lambert maneuver between two different points.
 
         Parameters
         ----------
@@ -257,10 +276,10 @@ class Maneuver(object):
         r_i = orbit_i.r
         r_f = orbit_f.r
 
-        # Time of flight is solved by substracting both orbit epochs
+        # Time of flight is solved by subtracting both orbit epochs
         tof = orbit_f.epoch - orbit_i.epoch
 
-        # Compute all posible solutions to the Lambert transfer
+        # Compute all possible solutions to the Lambert transfer
         sols = list(method(k, r_i, r_f, tof, **kwargs))
 
         # Return short or long solution
@@ -269,7 +288,10 @@ class Maneuver(object):
         else:
             dv_a, dv_b = sols[-1]
 
-        return cls((0 * u.s, dv_a - orbit_i.v), (tof.to(u.s), orbit_f.v - dv_b))
+        return cls(
+            (0 * u.s, (dv_a - orbit_i.v).decompose()),
+            (tof.to(u.s), (orbit_f.v - dv_b).decompose()),
+        )
 
     def get_total_time(self):
         """Returns total time of the maneuver.
