@@ -12,8 +12,8 @@ import pandas as pd
 from astropy.time import Time
 
 from poliastro.bodies import Sun
-from poliastro.frames import HeliocentricEclipticJ2000
-from poliastro.twobody.angles import M_to_nu
+from poliastro.frames.ecliptic import HeliocentricEclipticJ2000
+from poliastro.twobody.angles import D_to_nu, E_to_nu, F_to_nu, M_to_D, M_to_E, M_to_F
 from poliastro.twobody.orbit import Orbit
 
 AST_DTYPE = np.dtype(
@@ -345,29 +345,38 @@ def orbit_from_name(name):
 def orbit_from_record(record):
     """Return :py:class:`~poliastro.twobody.orbit.Orbit` given a record.
 
-        Retrieve info from JPL DASTCOM5 database.
+    Retrieve info from JPL DASTCOM5 database.
 
-        Parameters
-        ----------
-        record : int
-            Object record.
+    Parameters
+    ----------
+    record : int
+        Object record.
 
-        Returns
-        -------
-        orbit : ~poliastro.twobody.orbit.Orbit
-            NEO orbit.
+    Returns
+    -------
+    orbit : ~poliastro.twobody.orbit.Orbit
+        NEO orbit.
 
-        """
+    """
     body_data = read_record(record)
     a = body_data["A"].item() * u.au
     ecc = body_data["EC"].item() * u.one
     inc = body_data["IN"].item() * u.deg
     raan = body_data["OM"].item() * u.deg
     argp = body_data["W"].item() * u.deg
-    m = body_data["MA"].item() * u.deg
-    nu = M_to_nu(m, ecc)
+    M = body_data["MA"].item() * u.deg
     epoch = Time(body_data["EPOCH"].item(), format="jd", scale="tdb")
 
+    # NOTE: It is unclear how this conversion should happen,
+    # see https://ssd-api.jpl.nasa.gov/doc/sbdb.html
+    if ecc < 1:
+        M = (M + np.pi * u.rad) % (2 * np.pi * u.rad) - np.pi * u.rad
+        nu = E_to_nu(M_to_E(M, ecc), ecc)
+    elif ecc == 1:
+        nu = D_to_nu(M_to_D(M))
+    else:
+        nu = F_to_nu(M_to_F(M, ecc), ecc)
+
     orbit = Orbit.from_classical(Sun, a, ecc, inc, raan, argp, nu, epoch)
     orbit._frame = HeliocentricEclipticJ2000(obstime=epoch)
     return orbit
@@ -392,7 +401,7 @@ def record_from_name(name):
     records = []
     lines = string_record_from_name(name)
     for line in lines:
-        records.append(int(line[:6].lstrip()))
+        records.append(int(line[:8].lstrip()))
     return records
 
 
@@ -585,6 +594,6 @@ def entire_db():
     )
     df = ast_database.append(com_database, ignore_index=True)
     df[["NAME", "DESIG", "IREF"]] = df[["NAME", "DESIG", "IREF"]].apply(
-        lambda x: x.str.strip().str.decode("utf-8")
+        lambda x: x.str.decode("utf-8").str.strip()
     )
     return df
