@@ -7,7 +7,8 @@ from astropy import units as u
 
 from poliastro.bodies import Body
 
-from ._states import RVState
+from ..frames import Planes
+from .states import RVState
 
 u.kms = u.km / u.s
 u.km3s2 = u.km ** 3 / u.s ** 2
@@ -35,7 +36,9 @@ def state_from_vector(func):
     @wraps(func)
     def wrapper(t, u_, k, *args, **kwargs):
         r, v = u_[:3], u_[3:]
-        ss = RVState(Body(None, k * u.km3s2, "_Dummy"), r * u.km, v * u.kms)
+        ss = RVState(
+            Body(None, k * u.km3s2, "_Dummy"), r * u.km, v * u.kms, Planes.EARTH_EQUATOR
+        )
 
         return func(t, ss, *args, **kwargs)
 
