@@ -4,9 +4,9 @@ different propagators available at poliastro:
 +-------------+------------+-----------------+-----------------+
 |  Propagator | Elliptical |    Parabolic    |    Hyperbolic   |
 +-------------+------------+-----------------+-----------------+
-| mean_motion |      ✓     |        ✓        |        ✓        |
+|  farnocchia |      ✓     |        ✓        |        ✓        |
 +-------------+------------+-----------------+-----------------+
-|    kepler   |      ✓     |        ✓        |        ✓        |
+|   vallado   |      ✓     |        ✓        |        ✓        |
 +-------------+------------+-----------------+-----------------+
 |   mikkola   |      ✓     | NOT IMPLEMENTED |        ✓        |
 +-------------+------------+-----------------+-----------------+
@@ -25,24 +25,23 @@ different propagators available at poliastro:
 import functools
 
 import numpy as np
-from astropy import time, units as u
+from astropy import units as u
 from astropy.coordinates import CartesianDifferential, CartesianRepresentation
-from scipy.integrate import solve_ivp
+from scipy.integrate import DOP853, solve_ivp
 
 from poliastro.core.propagation import (
     danby as danby_fast,
+    farnocchia as farnocchia_fast,
     func_twobody,
     gooding as gooding_fast,
-    kepler as kepler_fast,
     markley as markley_fast,
-    mean_motion as mean_motion_fast,
     mikkola as mikkola_fast,
     pimienta as pimienta_fast,
+    vallado as vallado_fast,
 )
-from poliastro.integrators import DOP835
 
 
-def cowell(k, r, v, tofs, rtol=1e-11, *, ad=None, **ad_kwargs):
+def cowell(k, r, v, tofs, rtol=1e-11, *, events=None, ad=None, **ad_kwargs):
     """Propagates orbit using Cowell's formulation.
 
     Parameters
@@ -57,6 +56,9 @@ def cowell(k, r, v, tofs, rtol=1e-11, *, ad=None, **ad_kwargs):
         Array of times to propagate.
     rtol : float, optional
         Maximum relative error permitted, default to 1e-10.
+    events : function(t, u(t)), optional
+        passed to solve_ivp: integration stops when this function
+        returns <= 0., assuming you set events.terminal=True
     ad : function(t0, u, k), optional
          Non Keplerian acceleration (km/s2), default to None.
 
@@ -101,24 +103,32 @@ def cowell(k, r, v, tofs, rtol=1e-11, *, ad=None, **ad_kwargs):
         u0,
         rtol=rtol,
         atol=1e-12,
-        method=DOP835,
+        method=DOP853,
         dense_output=True,
+        events=events,
     )
     if not result.success:
         raise RuntimeError("Integration failed")
 
+    t_end = (
+        min(result.t_events[0]) if result.t_events and len(result.t_events[0]) else None
+    )
+
     rrs = []
     vvs = []
     for i in range(len(tofs)):
-        y = result.sol(tofs[i])
+        t = tofs[i]
+        if t_end is not None and t > t_end:
+            t = t_end
+        y = result.sol(t)
         rrs.append(y[:3])
         vvs.append(y[3:])
 
     return rrs * u.km, vvs * u.km / u.s
 
 
-def mean_motion(k, r, v, tofs, **kwargs):
-    """Propagates orbit using Cowell's formulation.
+def farnocchia(k, r, v, tofs, **kwargs):
+    """Propagates orbit.
 
     Parameters
     ----------
@@ -144,7 +154,7 @@ def mean_motion(k, r, v, tofs, **kwargs):
     v0 = v.to(u.km / u.s).value
     tofs = tofs.to(u.s).value
 
-    results = [mean_motion_fast(k, r0, v0, tof) for tof in tofs]
+    results = [farnocchia_fast(k, r0, v0, tof) for tof in tofs]
     # TODO: Rewrite to avoid iterating twice
     return (
         [result[0] for result in results] * u.km,
@@ -152,7 +162,7 @@ def mean_motion(k, r, v, tofs, **kwargs):
     )
 
 
-def kepler(k, r, v, tofs, numiter=350, **kwargs):
+def vallado(k, r, v, tofs, numiter=350, **kwargs):
     """Propagates Keplerian orbit.
 
     Parameters
@@ -203,7 +213,7 @@ def kepler(k, r, v, tofs, numiter=350, **kwargs):
 
 def _kepler(k, r0, v0, tof, *, numiter):
     # Compute Lagrange coefficients
-    f, g, fdot, gdot = kepler_fast(k, r0, v0, tof, numiter)
+    f, g, fdot, gdot = vallado_fast(k, r0, v0, tof, numiter)
 
     assert np.abs(f * gdot - fdot * g - 1) < 1e-5  # Fixed tolerance
 
@@ -426,7 +436,7 @@ def danby(k, r, v, tofs, rtol=1e-8):
     )
 
 
-def propagate(orbit, time_of_flight, *, method=mean_motion, rtol=1e-10, **kwargs):
+def propagate(orbit, time_of_flight, *, method=farnocchia, rtol=1e-10, **kwargs):
     """Propagate an orbit some time and return the result.
 
     Parameters
@@ -436,10 +446,15 @@ def propagate(orbit, time_of_flight, *, method=mean_motion, rtol=1e-10, **kwargs
     time_of_flight : ~astropy.time.TimeDelta
         Time of propagation.
     method : callable, optional
-        Propagation method, default to mean_motion.
+        Propagation method, default to farnocchia.
     rtol : float, optional
         Relative tolerance, default to 1e-10.
 
+    Returns
+    -------
+    astropy.coordinates.CartesianRepresentation
+        Propagation coordinates.
+
     """
 
     # Check if propagator fulfills orbit requirements
@@ -458,14 +473,13 @@ def propagate(orbit, time_of_flight, *, method=mean_motion, rtol=1e-10, **kwargs
     else:
         pass
 
-    # Use the highest precision we can afford
-    # np.atleast_1d does not work directly on TimeDelta objects
-    jd1 = np.atleast_1d(time_of_flight.jd1)
-    jd2 = np.atleast_1d(time_of_flight.jd2)
-    time_of_flight = time.TimeDelta(jd1, jd2, format="jd", scale=time_of_flight.scale)
-
     rr, vv = method(
-        orbit.attractor.k, orbit.r, orbit.v, time_of_flight.to(u.s), rtol=rtol, **kwargs
+        orbit.attractor.k,
+        orbit.r,
+        orbit.v,
+        time_of_flight.reshape(-1).to(u.s),
+        rtol=rtol,
+        **kwargs
     )
 
     # TODO: Turn these into unit tests
@@ -480,8 +494,8 @@ def propagate(orbit, time_of_flight, *, method=mean_motion, rtol=1e-10, **kwargs
 
 
 ELLIPTIC_PROPAGATORS = [
-    mean_motion,
-    kepler,
+    farnocchia,
+    vallado,
     mikkola,
     markley,
     pimienta,
@@ -489,12 +503,11 @@ ELLIPTIC_PROPAGATORS = [
     danby,
     cowell,
 ]
-PARABOLIC_PROPAGATORS = [mean_motion, kepler, mikkola, pimienta, gooding, cowell]
+PARABOLIC_PROPAGATORS = [farnocchia, vallado, mikkola, pimienta, gooding, cowell]
 HYPERBOLIC_PROPAGATORS = [
-    mean_motion,
-    kepler,
+    farnocchia,
+    vallado,
     mikkola,
-    kepler,
     pimienta,
     gooding,
     danby,
