@@ -8,10 +8,11 @@ References
 
 """
 import numpy as np
+from numpy import cross
+from numpy.linalg import norm
 
 from poliastro.core.elements import rv2coe
 from poliastro.core.thrust.change_argp import extra_quantities
-from poliastro.core.util import cross, norm
 
 
 def change_argp(k, a, ecc, argp_0, argp_f, f):
